### R code from vignette source 'BSM_and_Greeks.Rnw'

###################################################
### code chunk number 1: BSM_and_Greeks.Rnw:16-19
###################################################
library(knitr)
suppressPackageStartupMessages(library(GARPFRM))
opts_chunk$set(tidy=FALSE, warning=FALSE, fig.width=5, fig.height=5)


###################################################
### code chunk number 2: BSM_and_Greeks.Rnw:68-81
###################################################
# Demonstrate the property of the Black-Scholes-Merton formula for a call 
# option as the underlying price becomes very large
S0 <- seq(100, 100000, 100)
eu.call <- optionSpec(style = "european", 
                      type = "call", 
                      S0 = S0,
                      K = 100,
                      maturity = 1, 
                      r = 0.1, 
                      volatility = 0.2)
call.price <- optionValue(option = eu.call, method = "Black-Scholes")
plot(S0, call.price, xlab="Underlying Price", ylab="Call Price",
     main="Call price as S_0 becomes very large", type="l")


###################################################
### code chunk number 3: BSM_and_Greeks.Rnw:84-99
###################################################
# Demonstrate the property of the Black-Scholes-Merton formula for a call 
# option as the volatility approaches 0
sigma <- seq(0.2, 0, -0.01)
eu.call <- optionSpec(style = "european", 
                      type = "call", 
                      S0 = 100,
                      K = 100,
                      maturity = 1, 
                      r = 0.1, 
                      volatility = sigma)
call <- optionValue(option = eu.call, method = "Black-Scholes")
# S_0 - K * e^{-r T}
100 - 100 * exp(-0.1 * 1)
plot(sigma, call, ylab="Call Price", xlab="Volatility", 
     main="Call price as volatility approaches 0", type = "l")


###################################################
### code chunk number 4: BSM_and_Greeks.Rnw:104-124
###################################################
# The stock price 6 months for the expiration of an option is $42, 
# the exercise price of the option is $40, the risk-free interest 
# rate is 10% per annum, and the volatility is 20% per annum.

# Price the European call option
eu.call <- optionSpec(style = "european", 
                      type = "call", 
                      S0 = 42, 
                      K = 40,
                      maturity = 0.5, 
                      r = 0.1, 
                      volatility = 0.2)
call <- optionValue(option = eu.call, method = "Black-Scholes")
call

# Price the European put option
eu.put <- eu.call
eu.put$type <- "put"
put <- optionValue(option = eu.put, method = "Black-Scholes")
put


###################################################
### code chunk number 5: BSM_and_Greeks.Rnw:129-138
###################################################
# Compute the implied volatility of a European call option with a 
# price of $1.875 and S_0 = 21, K = 20, r = 0.1, and T = 0.25
eu.call <- optionSpec(style = "european", 
                      type = "call", 
                      S0 = 21, 
                      K = 20,
                      maturity = 0.25, 
                      r = 0.1)
impliedVolatility(eu.call, 1.875)


###################################################
### code chunk number 6: BSM_and_Greeks.Rnw:144-161
###################################################
# Consider a European call option on a stock when there are 
# ex-dividend dates in two months and five months. The dividend 
# on each ex-dividend date is expected to be \$0.50. The current 
# share price is \$40, the exercise price is \$40, and the stock 
# price volatility is 30\% per annum, the risk-free rate of 
# interest is 9\% per annum, and the time to maturity is 6 months.

# Subtract the present value of the dividends from the underlying price
S0 <- 40 - (0.5 * exp(-0.09 * 2 / 12) + 0.5 * exp(-0.09 * 5 / 12))
eu.call <- optionSpec(style = "european", 
                      type = "call", 
                      S0 = S0, 
                      K = 40,
                      maturity = 0.5, 
                      r = 0.09,
                      volatility = 0.3)
optionValue(eu.call, "Black-Scholes")


###################################################
### code chunk number 7: BSM_and_Greeks.Rnw:169-188
###################################################
# Specify European call and put options where the current stock price is
# $49, the strike price is $50, the risk-free rate is 5%, the time to
# maturity is 20 weeks, and the volatility is 20%.

eu.call <- optionSpec(style = "european", 
                      type = "call", 
                      S0 = 49, 
                      K = 50,
                      maturity = 20/52, 
                      r = 0.05,
                      volatility = 0.2)

eu.put <- optionSpec(style = "european", 
                      type = "put", 
                      S0 = 49, 
                      K = 50,
                      maturity = 20/52, 
                      r = 0.05,
                     volatility = 0.2)


###################################################
### code chunk number 8: BSM_and_Greeks.Rnw:201-203
###################################################
# Compute the delta of the European call option
computeGreeks(eu.call, "delta")


###################################################
### code chunk number 9: BSM_and_Greeks.Rnw:207-212
###################################################
# Delta as the underlying price varies
computeGreeks(eu.call, "delta", prices = seq(20, 80, 1), 
              plot = TRUE, main="Delta of call")
computeGreeks(eu.put, "delta", prices = seq(20, 80, 1), 
              plot = TRUE, main="Delta of put")


###################################################
### code chunk number 10: BSM_and_Greeks.Rnw:215-229
###################################################
# Delta as the time to maturity varies for in the money, at the money, and
# out of the money call options
maturity <- seq(0.01, 1, 0.05)
plot(maturity, xlim = range(maturity), ylim = c(0,1), 
     type="n", xlab="Time to expiration", ylab="Delta")
lines(x = maturity, y = deltaBS(52, 50, 0.05, 0, 0.2, maturity, "call"), 
      lty=2, col="blue")
lines(x = maturity, y = deltaBS(50, 50, 0.05, 0, 0.2, maturity, "call"), 
      lty=1, col="black")
lines(x = maturity, y = deltaBS(48, 50, 0.05, 0, 0.2, maturity, "call"), 
      lty=3, col="red")
title("Delta of call")
legend("topright", legend=c("In the money", "At the money", "Out of the money"),
       lty=c(2,1,3), col=c("blue", "black", "red"), bty="n", cex=0.8)


###################################################
### code chunk number 11: BSM_and_Greeks.Rnw:246-247
###################################################
100000 * 0.533 - 200000 * 0.468 - 50000 * -0.508


###################################################
### code chunk number 12: BSM_and_Greeks.Rnw:264-266
###################################################
# Compute the theta of the European call option
computeGreeks(eu.call, "theta")


###################################################
### code chunk number 13: BSM_and_Greeks.Rnw:269-272
###################################################
# Theta as the underlying price varies
computeGreeks(eu.call, "theta", prices = seq(20, 80, 1), 
              plot = TRUE, main="Theta of call")


###################################################
### code chunk number 14: BSM_and_Greeks.Rnw:275-289
###################################################
# Theta as the time to maturity varies for in the money, at the money, and
# out of the money call options
maturity <- seq(0.01, 1, 0.05)
plot(maturity, xlim = range(maturity), ylim = c(-15,0), 
     type="n", xlab="Time to expiration", ylab="Theta")
lines(x = maturity, y = thetaBS(55, 50, 0.05, 0, 0.2, maturity, "call"), 
      lty=2, col="blue")
lines(x = maturity, y = thetaBS(50, 50, 0.05, 0, 0.2, maturity, "call"), 
      lty=1, col="black")
lines(x = maturity, y = thetaBS(45, 50, 0.05, 0, 0.2, maturity, "call"), 
      lty=3, col="red")
title("Theta of call")
legend("topright", legend=c("In the money", "At the money", "Out of the money"),
       lty=c(2,1,3), col=c("blue", "black", "red"), bty="n", cex=0.8)


###################################################
### code chunk number 15: BSM_and_Greeks.Rnw:302-304
###################################################
# Compute the gamma of the European call option
computeGreeks(eu.call, "gamma")


###################################################
### code chunk number 16: BSM_and_Greeks.Rnw:307-310
###################################################
# Gamma as the underlying price varies
computeGreeks(eu.call, "gamma", prices = seq(20, 80, 1), 
              plot = TRUE, main="Gamma of call")


###################################################
### code chunk number 17: BSM_and_Greeks.Rnw:313-327
###################################################
# Gamma as the time to maturity varies for in the money, at the money, and
# out of the money call options
maturity <- seq(0.01, 1, 0.05)
plot(maturity, xlim = range(maturity), ylim = c(0,0.5), 
     type="n", xlab="Time to expiration", ylab="Gamma")
lines(x = maturity, y = gammaBS(55, 50, 0.05, 0, 0.2, maturity, "call"), 
      lty=2, col="blue")
lines(x = maturity, y = gammaBS(50, 50, 0.05, 0, 0.2, maturity, "call"), 
      lty=1, col="black")
lines(x = maturity, y = gammaBS(45, 50, 0.05, 0, 0.2, maturity, "call"), 
      lty=3, col="red")
title("Gamma of call")
legend("topright", legend=c("In the money", "At the money", "Out of the money"),
       lty=c(2,1,3), col=c("blue", "black", "red"), bty="n", cex=0.8)


###################################################
### code chunk number 18: BSM_and_Greeks.Rnw:340-342
###################################################
# Compute the vega of a European call option
computeGreeks(eu.call, "vega")


###################################################
### code chunk number 19: BSM_and_Greeks.Rnw:345-348
###################################################
# Vega as the underlying price varies
computeGreeks(eu.call, "vega", prices = seq(20, 80, 1), 
              plot = TRUE, main="Vega of call")


###################################################
### code chunk number 20: BSM_and_Greeks.Rnw:351-365
###################################################
# Vega as the time to maturity varies for in the money, at the money, and
# out of the money call options
maturity <- seq(0.01, 1, 0.05)
plot(maturity, xlim = range(maturity), ylim = c(0,20), 
     type="n", xlab="Time to expiration", ylab="Theta")
lines(x = maturity, y = vegaBS(55, 50, 0.05, 0, 0.2, maturity, "call"), 
      lty=2, col="blue")
lines(x = maturity, y = vegaBS(50, 50, 0.05, 0, 0.2, maturity, "call"), 
      lty=1, col="black")
lines(x = maturity, y = vegaBS(45, 50, 0.05, 0, 0.2, maturity, "call"), 
      lty=3, col="red")
title("Vega of call")
legend("topleft", legend=c("In the money", "At the money", "Out of the money"),
       lty=c(2,1,3), col=c("blue", "black", "red"), bty="n", cex=0.8)


###################################################
### code chunk number 21: BSM_and_Greeks.Rnw:378-380
###################################################
# Compute the rho of the European call option
computeGreeks(eu.call, "rho")


###################################################
### code chunk number 22: BSM_and_Greeks.Rnw:383-386
###################################################
# Rho as the unerlying price varies
computeGreeks(eu.call, "rho", prices = seq(20, 80, 1), 
              plot = TRUE, main="Rho of call")


###################################################
### code chunk number 23: BSM_and_Greeks.Rnw:389-403
###################################################
# Rho as the time to maturity varies for in the money, at the money, and
# out of the money call options
maturity <- seq(0.01, 1, 0.05)
plot(maturity, xlim = range(maturity), ylim = c(0,40), 
     type="n", xlab="Time to expiration", ylab="Theta")
lines(x = maturity, y = rhoBS(55, 50, 0.05, 0, 0.2, maturity, "call"), 
      lty=2, col="blue")
lines(x = maturity, y = rhoBS(50, 50, 0.05, 0, 0.2, maturity, "call"), 
      lty=1, col="black")
lines(x = maturity, y = rhoBS(45, 50, 0.05, 0, 0.2, maturity, "call"), 
      lty=3, col="red")
title("Rho of call")
legend("topleft", legend=c("In the money", "At the money", "Out of the money"),
       lty=c(2,1,3), col=c("blue", "black", "red"), bty="n", cex=0.8)


###################################################
### code chunk number 24: BSM_and_Greeks.Rnw:409-418
###################################################
eu.put <- optionSpec(style = "european", 
                     type = "put", 
                     S0 = 90, 
                     K = 87,
                     maturity = 0.5, 
                     r = 0.09,
                     volatility = 0.25,
                     q = 0.03)
computeGreeks(eu.put, "delta")


